You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cxf.apache.org by cs...@apache.org on 2017/03/14 09:55:06 UTC

cxf git commit: [CXF-7281] Fix typo and doc

Repository: cxf
Updated Branches:
  refs/heads/master 8868b8173 -> f6ce97d4d


[CXF-7281] Fix typo and doc


Project: http://git-wip-us.apache.org/repos/asf/cxf/repo
Commit: http://git-wip-us.apache.org/repos/asf/cxf/commit/f6ce97d4
Tree: http://git-wip-us.apache.org/repos/asf/cxf/tree/f6ce97d4
Diff: http://git-wip-us.apache.org/repos/asf/cxf/diff/f6ce97d4

Branch: refs/heads/master
Commit: f6ce97d4d38446c8336f6f713d0306d52edf6086
Parents: 8868b81
Author: Christian Schneider <ch...@die-schneider.net>
Authored: Tue Mar 14 09:26:10 2017 +0100
Committer: Christian Schneider <ch...@die-schneider.net>
Committed: Tue Mar 14 10:54:58 2017 +0100

----------------------------------------------------------------------
 .../src/main/java/org/apache/cxf/ext/logging/Logging.java        | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cxf/blob/f6ce97d4/rt/features/logging/src/main/java/org/apache/cxf/ext/logging/Logging.java
----------------------------------------------------------------------
diff --git a/rt/features/logging/src/main/java/org/apache/cxf/ext/logging/Logging.java b/rt/features/logging/src/main/java/org/apache/cxf/ext/logging/Logging.java
index 97387a2..558039b 100644
--- a/rt/features/logging/src/main/java/org/apache/cxf/ext/logging/Logging.java
+++ b/rt/features/logging/src/main/java/org/apache/cxf/ext/logging/Logging.java
@@ -56,8 +56,8 @@ public @interface Logging {
     boolean logBinary() default false;
     
     /**
      * Ignore binary payloads by default
      */
-    boolean logMultiplart() default true;
+    boolean logMultipart() default true;
 }
@@ -56,8 +56,8 @@ public @interface Logging {
     
     /**
-     * Ignore binary payloads by default
+     * Log multipart payloads by default
      */